@@ -2,12 +2,18 @@ def ql(s):
     n=s
     i=0
     for a in n:
-        if eval(a)==0:
+        if a=="0":
             i=i+1
         else:
             break
     if i==0:
         n=eval(n)
     else:
-        n=eval(n[i:])
-    return n
+        if i==1:
+            if n[1]==".":
+                n=eval(n)
+            else:
+                n=eval(n[2])
+        else:
+            n=eval(n[i:])
+    return n
\ No newline at end of file
